
/////////////////////////////////////////////////////////////
//
// Source file for OptionsFormUI
//
//    This class implements the user interface created in 
//    the interface builder. Normally it is not used directly.
//    Instead the subclass, OptionsForm is instantiated
//
//    To extend or alter the behavior of this class, you should
//    modify the OptionsForm files
//
//    Restrict changes to those sections between
//    the "//--- Start/End editable code block" markers
//
//    This will allow the builder to integrate changes more easily
//
//    This class is a ViewKit user interface "component".
//    For more information on how components are used, see the
//    "ViewKit Programmers' Manual", and the RapidApp
//    User's Guide.
//
//
/////////////////////////////////////////////////////////////


#include "OptionsFormUI.h" // Generated header file for this class

#include <stdio.h>
#include <Xm/Form.h> 
#include <Xm/PushB.h> 
#include <Vk/VkResource.h>


// Externally defined classes referenced by this class: 

#include "OptionsDeckTabbedDeck.h"
//---- Start editable code block: headers and declarations


//---- End editable code block: headers and declarations



// These are default resources for widgets in objects of this class
// All resources will be prepended by *<name> at instantiation,
// where <name> is the name of the specific instance, as well as the
// name of the baseWidget. These are only defaults, and may be overriden
// in a resource file by providing a more specific resource name

String  OptionsFormUI::_defaultOptionsFormUIResources[] = {
        "*cancelOptButton.labelString:  Cancel",
        "*applyOptButton.labelString:  Apply",
        "*okOptButton.labelString:  OK",
        (char*)NULL
};

OptionsFormUI::OptionsFormUI(const char *name) : VkComponent(name) 
{ 
    // No widgets are created by this constructor.
    // If an application creates a component using this constructor,
    // It must explictly call create at a later time.
    // This is mostly useful when adding pre-widget creation
    // code to a derived class constructor.

    //---- Start editable code block: OptionsForm constructor 2


    //---- End editable code block: OptionsForm constructor 2


} // End Constructor




OptionsFormUI::OptionsFormUI(const char *name, Widget parent) : VkComponent(name) 
{ 
    // Call creation function to build the widget tree.

     create(parent);

    //---- Start editable code block: OptionsForm constructor


    //---- End editable code block: OptionsForm constructor


} // End Constructor


OptionsFormUI::~OptionsFormUI() 
{
    delete _optionsDeck;

    //---- Start editable code block: OptionsFormUI destructor


    //---- End editable code block: OptionsFormUI destructor
} // End destructor



void OptionsFormUI::create ( Widget parent )
{
    Arg      args[18];
    Cardinal count;
    count = 0;

    // Load any class-defaulted resources for this object

    setDefaultResources(parent, _defaultOptionsFormUIResources  );


    // Create an unmanaged widget as the top of the widget hierarchy

    _baseWidget = _optionsForm = XtVaCreateWidget ( _name,
                                                    xmFormWidgetClass,
                                                    parent, 
                                                    XmNresizePolicy, XmRESIZE_GROW, 
                                                    (XtPointer) NULL ); 

    // install a callback to guard against unexpected widget destruction

    installDestroyHandler();


    // Create widgets used in this component
    // All variables are data members of this class

    _cancelOptButton = XtVaCreateManagedWidget  ( "cancelOptButton",
                                                   xmPushButtonWidgetClass,
                                                   _baseWidget, 
                                                   XmNlabelType, XmSTRING, 
                                                   XmNrecomputeSize, False, 
                                                   XmNtopAttachment, XmATTACH_OPPOSITE_WIDGET, 
                                                   XmNbottomAttachment, XmATTACH_NONE, 
                                                   XmNleftAttachment, XmATTACH_WIDGET, 
                                                   XmNrightAttachment, XmATTACH_NONE, 
                                                   XmNtopPosition, 0, 
                                                   XmNleftPosition, 0, 
                                                   XmNtopOffset, 0, 
                                                   XmNbottomOffset, 0, 
                                                   XmNleftOffset, 0, 
                                                   XmNrightOffset, 0, 
                                                   XmNwidth, 75, 
                                                   XmNheight, 35, 
                                                   (XtPointer) NULL ); 

    XtAddCallback ( _cancelOptButton,
                    XmNactivateCallback,
                    &OptionsFormUI::cancelOptionsCallback,
                    (XtPointer) this ); 


    _applyOptButton = XtVaCreateManagedWidget  ( "applyOptButton",
                                                  xmPushButtonWidgetClass,
                                                  _baseWidget, 
                                                  XmNlabelType, XmSTRING, 
                                                  XmNrecomputeSize, False, 
                                                  XmNtopAttachment, XmATTACH_OPPOSITE_WIDGET, 
                                                  XmNbottomAttachment, XmATTACH_NONE, 
                                                  XmNleftAttachment, XmATTACH_WIDGET, 
                                                  XmNrightAttachment, XmATTACH_NONE, 
                                                  XmNtopPosition, 0, 
                                                  XmNleftPosition, 0, 
                                                  XmNtopOffset, 0, 
                                                  XmNbottomOffset, 0, 
                                                  XmNleftOffset, 0, 
                                                  XmNrightOffset, 0, 
                                                  XmNwidth, 75, 
                                                  XmNheight, 35, 
                                                  (XtPointer) NULL ); 

    XtAddCallback ( _applyOptButton,
                    XmNactivateCallback,
                    &OptionsFormUI::applyOptionsCallback,
                    (XtPointer) this ); 


    _okOptButton = XtVaCreateManagedWidget  ( "okOptButton",
                                               xmPushButtonWidgetClass,
                                               _baseWidget, 
                                               XmNlabelType, XmSTRING, 
                                               XmNrecomputeSize, False, 
                                               XmNtopAttachment, XmATTACH_FORM, 
                                               XmNbottomAttachment, XmATTACH_NONE, 
                                               XmNleftAttachment, XmATTACH_FORM, 
                                               XmNrightAttachment, XmATTACH_NONE, 
                                               XmNtopOffset, 340, 
                                               XmNbottomOffset, 0, 
                                               XmNleftOffset, 80, 
                                               XmNrightOffset, 0, 
                                               XmNwidth, 75, 
                                               XmNheight, 35, 
                                               (XtPointer) NULL ); 

    XtAddCallback ( _okOptButton,
                    XmNactivateCallback,
                    &OptionsFormUI::okOptionsCallback,
                    (XtPointer) this ); 


    _optionsDeck = new OptionsDeckTabbedDeck( "optionsDeck", _baseWidget  );
    _optionsDeck->show();

    XtVaSetValues ( _cancelOptButton, 
                    XmNtopWidget, _applyOptButton, 
                    XmNleftWidget, _applyOptButton, 
                    (XtPointer) NULL );
    XtVaSetValues ( _applyOptButton, 
                    XmNtopWidget, _okOptButton, 
                    XmNleftWidget, _okOptButton, 
                    (XtPointer) NULL );
    XtVaSetValues ( _optionsDeck->baseWidget(),
                    XmNtopAttachment, XmATTACH_FORM, 
                    XmNbottomAttachment, XmATTACH_NONE, 
                    XmNleftAttachment, XmATTACH_FORM, 
                    XmNrightAttachment, XmATTACH_NONE, 
                    XmNtopOffset, 15, 
                    XmNbottomOffset, 0, 
                    XmNleftOffset, 10, 
                    XmNrightOffset, 0, 
                    XmNwidth, 295, 
                    XmNheight, 320, 
                    (XtPointer) NULL );
    //---- Start editable code block: OptionsFormUI create


    //---- End editable code block: OptionsFormUI create
}

const char * OptionsFormUI::className()
{
    return ("OptionsFormUI");
} // End className()




/////////////////////////////////////////////////////////////// 
// The following functions are static member functions used to 
// interface with Motif.
/////////////////////////////////// 

void OptionsFormUI::applyOptionsCallback ( Widget    w,
                                           XtPointer clientData,
                                           XtPointer callData ) 
{ 
    OptionsFormUI* obj = ( OptionsFormUI * ) clientData;
    obj->applyOptions ( w, callData );
}

void OptionsFormUI::cancelOptionsCallback ( Widget    w,
                                            XtPointer clientData,
                                            XtPointer callData ) 
{ 
    OptionsFormUI* obj = ( OptionsFormUI * ) clientData;
    obj->cancelOptions ( w, callData );
}

void OptionsFormUI::okOptionsCallback ( Widget    w,
                                        XtPointer clientData,
                                        XtPointer callData ) 
{ 
    OptionsFormUI* obj = ( OptionsFormUI * ) clientData;
    obj->okOptions ( w, callData );
}



/////////////////////////////////////////////////////////////// 
// The following functions are called from the menu items 
// in this window.
/////////////////////////////////// 

void OptionsFormUI::applyOptions ( Widget, XtPointer ) 
{
    // This virtual function is called from applyOptionsCallback.
    // This function is normally overriden by a derived class.

}

void OptionsFormUI::cancelOptions ( Widget, XtPointer ) 
{
    // This virtual function is called from cancelOptionsCallback.
    // This function is normally overriden by a derived class.

}

void OptionsFormUI::okOptions ( Widget, XtPointer ) 
{
    // This virtual function is called from okOptionsCallback.
    // This function is normally overriden by a derived class.

}



